@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.26.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.27.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -28,6 +28,10 @@ has "doap_changelog" => (
     },
 );
 
+sub not_for_travis {
+    return $ENV{TRAVIS} ? () : @_;
+}
+
 
 
 
@@ -70,15 +74,15 @@ sub configure {
                 format    => '%-9v %{yyyy-MM-dd}d',
             } ],
         'MetaProvides::Package',
-        qw/ MatchManifest
-          ManifestSkip /,
+        not_for_travis( 'MatchManifest' ),
+        qw/  ManifestSkip /,
         [ 'Git::GatherDir' => {
                 include_dotfiles => $arg->{include_dotfiles},
               } ],
         qw/ ExecDir
           PkgVersion /,
           [ Authority => { 
-            ( authority => $arg->{authority} ) x !!$arg->{authority}  
+            authority => $arg->{authority} // 'cpan:YANICK'
           } ],
           qw/ Test::ReportPrereqs
           Signature /,
@@ -182,7 +186,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.26.0
+version 0.27.0
 
 =head1 DESCRIPTION
 
